server_client_20141211_234315

### config1 : test_client_isolation

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.27334904671 sec | 5.39801096916 sec

Error message: Did not properly handle faulty client

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.84 | 0.28 | 0.21 | 0.24 | 0.3 | 0.39 | 0.42 | 0.67 | 0.086
qps | 332.00 | 220.50 | 109.00 | 220.50 | 276.25 | 309.70 | 320.85 | 329.77 | 111.50

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.245
server1-perf | latency | mean lt 0.33 | 0.28047845805
server1-perf | qps | mean lt 7.0 | 220.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | None
client1-perf | latency | mean lt 35.0 | None
client1-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None